@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python3.3
 #
 # wajig - Debian Command Line System Administrator
 #
@@ -26,7 +26,7 @@ import sys
 import commands
 import perform
 
-VERSION = "2.7.3"
+VERSION = "2.8"
 
 
 def main():
@@ -503,7 +503,7 @@ def main():
     function = commands.purgeorphans
     parser_purgeorphans = subparsers.add_parser("purgeorphans",
                           aliases=["purge-orphans"],
-                          parents=[parser_yesno, parser_auth, parser_teach],
+                          parents=[parser_yesno],
                           description=function.__doc__)
     parser_purgeorphans.set_defaults(func=function)
 
@@ -574,7 +574,7 @@ def main():
     function = commands.removeorphans
     parser_removeorphans = subparsers.add_parser("removeorphans",
                            aliases=["remove-orphans"],
-                           parents=[parser_teach],
+                           parents=[parser_yesno],
                            description=function.__doc__)
     parser_removeorphans.set_defaults(func=function)
 
@@ -619,9 +619,13 @@ def main():
 
     function = commands.search
     parser_search = subparsers.add_parser("search",
-                    parents=[parser_verbose, parser_teach],
-                    description=function.__doc__)
+                    parents=[parser_teach],
+                    description=function.__doc__,
+                    formatter_class=argparse.RawDescriptionHelpFormatter)
     parser_search.add_argument("patterns", nargs="+")
+    help=("'-v' will also search short package desciption; "
+          "'-vv' will also search the short and long decription")
+    parser_search.add_argument("-v", "--verbose", action="count", help=help)
     parser_search.set_defaults(func=function)
 
     function = commands.searchapt
@@ -691,12 +695,12 @@ def main():
     parser_stop.add_argument("daemon")
     parser_stop.set_defaults(func=function)
 
-    function = commands.syslog
-    parser_syslog = subparsers.add_parser("syslog",
+    function = commands.aptlog
+    parser_aptlog = subparsers.add_parser("aptlog",
                     parents=[parser_teach],
                     aliases=["listlog"],
                     description=function.__doc__)
-    parser_syslog.set_defaults(func=function)
+    parser_aptlog.set_defaults(func=function)
 
     function = commands.tasksel
     parser_tasksel = subparsers.add_parser("tasksel",
